pub enum GovernanceError {
Show 81 variants
InvalidInstruction = 500,
RealmAlreadyExists = 501,
InvalidRealm = 502,
InvalidGoverningTokenMint = 503,
GoverningTokenOwnerMustSign = 504,
GoverningTokenOwnerOrDelegateMustSign = 505,
AllVotesMustBeRelinquishedToWithdrawGoverningTokens = 506,
InvalidTokenOwnerRecordAccountAddress = 507,
InvalidGoverningMintForTokenOwnerRecord = 508,
InvalidRealmForTokenOwnerRecord = 509,
InvalidProposalForProposalInstruction = 510,
InvalidSignatoryAddress = 511,
SignatoryAlreadySignedOff = 512,
SignatoryMustSign = 513,
InvalidProposalOwnerAccount = 514,
InvalidProposalForVoterRecord = 515,
InvalidGoverningTokenOwnerForVoteRecord = 516,
InvalidVoteThresholdPercentage = 517,
ProposalAlreadyExists = 518,
VoteAlreadyExists = 519,
NotEnoughTokensToCreateProposal = 520,
InvalidStateCannotEditSignatories = 521,
InvalidProposalState = 522,
InvalidStateCannotEditInstructions = 523,
InvalidStateCannotExecuteInstruction = 524,
CannotExecuteInstructionWithinHoldUpTime = 525,
InstructionAlreadyExecuted = 526,
InvalidInstructionIndex = 527,
InstructionHoldUpTimeBelowRequiredMin = 528,
InstructionAlreadyExists = 529,
InvalidStateCannotSignOff = 530,
InvalidStateCannotVote = 531,
InvalidStateCannotFinalize = 532,
InvalidStateCannotCancelProposal = 533,
VoteAlreadyRelinquished = 534,
CannotFinalizeVotingInProgress = 535,
ProposalVotingTimeExpired = 536,
InvalidSignatoryMint = 537,
InvalidGovernanceForProposal = 538,
InvalidGoverningMintForProposal = 539,
MintAuthorityMustSign = 540,
InvalidMintAuthority = 541,
MintHasNoAuthority = 542,
GplTokenAccountWithInvalidOwner = 543,
GplTokenMintWithInvalidOwner = 544,
GplTokenAccountNotInitialized = 545,
GplTokenAccountDoesNotExist = 546,
GplTokenInvalidTokenAccountData = 547,
GplTokenInvalidMintAccountData = 548,
GplTokenMintNotInitialized = 549,
GplTokenMintDoesNotExist = 550,
InvalidProgramDataAccountAddress = 551,
InvalidProgramDataAccountData = 552,
InvalidUpgradeAuthority = 553,
UpgradeAuthorityMustSign = 554,
ProgramNotUpgradable = 555,
InvalidTokenOwner = 556,
TokenOwnerMustSign = 557,
VoteThresholdPercentageTypeNotSupported = 558,
VoteWeightSourceNotSupported = 559,
ProposalCoolOffTimeNotSupported = 560,
GovernancePdaMustSign = 561,
InstructionAlreadyFlaggedWithError = 562,
InvalidRealmForGovernance = 563,
InvalidAuthorityForRealm = 564,
RealmHasNoAuthority = 565,
RealmAuthorityMustSign = 566,
InvalidGoverningTokenHoldingAccount = 567,
RealmCouncilMintChangeIsNotSupported = 568,
MintMaxVoteWeightSourceNotSupported = 569,
InvalidMaxVoteWeightSupplyFraction = 570,
NotEnoughTokensToCreateGovernance = 571,
TooManyOutstandingProposals = 572,
AllProposalsMustBeFinalisedToWithdrawGoverningTokens = 573,
InvalidVoterWeightRecordForRealm = 574,
InvalidVoterWeightRecordForGoverningTokenMint = 575,
InvalidVoterWeightRecordForTokenOwner = 576,
VoterWeightRecordExpired = 577,
InvalidRealmConfigForRealm = 578,
TokenOwnerRecordAlreadyExists = 579,
GoverningTokenDepositsNotAllowed = 580,
}Expand description
Errors that may be returned by the Governance program
Variants
InvalidInstruction = 500
Invalid instruction passed to program
RealmAlreadyExists = 501
Realm with the given name and governing mints already exists
InvalidRealm = 502
Invalid Realm
InvalidGoverningTokenMint = 503
Invalid Governing Token Mint
GoverningTokenOwnerMustSign = 504
Governing Token Owner must sign transaction
GoverningTokenOwnerOrDelegateMustSign = 505
Governing Token Owner or Delegate must sign transaction
AllVotesMustBeRelinquishedToWithdrawGoverningTokens = 506
All votes must be relinquished to withdraw governing tokens
InvalidTokenOwnerRecordAccountAddress = 507
Invalid Token Owner Record account address
InvalidGoverningMintForTokenOwnerRecord = 508
Invalid GoverningMint for TokenOwnerRecord
InvalidRealmForTokenOwnerRecord = 509
Invalid Realm for TokenOwnerRecord
InvalidProposalForProposalInstruction = 510
Invalid Proposal for ProposalInstruction
InvalidSignatoryAddress = 511
Invalid Signatory account address
SignatoryAlreadySignedOff = 512
Signatory already signed off
SignatoryMustSign = 513
Signatory must sign
InvalidProposalOwnerAccount = 514
Invalid Proposal Owner
InvalidProposalForVoterRecord = 515
Invalid Proposal for VoterRecord
InvalidGoverningTokenOwnerForVoteRecord = 516
Invalid GoverningTokenOwner for VoteRecord
InvalidVoteThresholdPercentage = 517
Invalid Governance config: Vote threshold percentage out of range“
ProposalAlreadyExists = 518
Proposal for the given Governance, Governing Token Mint and index already exists
VoteAlreadyExists = 519
Token Owner already voted on the Proposal
NotEnoughTokensToCreateProposal = 520
Owner doesn’t have enough governing tokens to create Proposal
InvalidStateCannotEditSignatories = 521
Invalid State: Can’t edit Signatories
InvalidProposalState = 522
Invalid Proposal state
InvalidStateCannotEditInstructions = 523
Invalid State: Can’t edit instructions
InvalidStateCannotExecuteInstruction = 524
Invalid State: Can’t execute instruction
CannotExecuteInstructionWithinHoldUpTime = 525
Can’t execute instruction within its hold up time
InstructionAlreadyExecuted = 526
Instruction already executed
InvalidInstructionIndex = 527
Invalid Instruction index
InstructionHoldUpTimeBelowRequiredMin = 528
Instruction hold up time is below the min specified by Governance
InstructionAlreadyExists = 529
Instruction at the given index for the Proposal already exists
InvalidStateCannotSignOff = 530
Invalid State: Can’t sign off
InvalidStateCannotVote = 531
Invalid State: Can’t vote
InvalidStateCannotFinalize = 532
Invalid State: Can’t finalize vote
InvalidStateCannotCancelProposal = 533
Invalid State: Can’t cancel Proposal
VoteAlreadyRelinquished = 534
Vote already relinquished
CannotFinalizeVotingInProgress = 535
Can’t finalize vote. Voting still in progress
ProposalVotingTimeExpired = 536
Proposal voting time expired
InvalidSignatoryMint = 537
Invalid Signatory Mint
InvalidGovernanceForProposal = 538
Proposal does not belong to the given Governance
InvalidGoverningMintForProposal = 539
Proposal does not belong to given Governing Mint“
MintAuthorityMustSign = 540
Current mint authority must sign transaction
InvalidMintAuthority = 541
Invalid mint authority
MintHasNoAuthority = 542
Mint has no authority
GplTokenAccountWithInvalidOwner = 543
–– GPL Token Tools Errors –– Invalid Token account owner
GplTokenMintWithInvalidOwner = 544
Invalid Mint account owner
GplTokenAccountNotInitialized = 545
Token Account is not initialized
GplTokenAccountDoesNotExist = 546
Token Account doesn’t exist
GplTokenInvalidTokenAccountData = 547
Token account data is invalid
GplTokenInvalidMintAccountData = 548
Token mint account data is invalid
GplTokenMintNotInitialized = 549
Token Mint is not initialized
GplTokenMintDoesNotExist = 550
Token Mint account doesn’t exist
InvalidProgramDataAccountAddress = 551
–– Bpf Upgradable Loader Tools Errors –– Invalid ProgramData account Address
InvalidProgramDataAccountData = 552
Invalid ProgramData account data
InvalidUpgradeAuthority = 553
Provided upgrade authority doesn’t match current program upgrade authority
UpgradeAuthorityMustSign = 554
Current program upgrade authority must sign transaction
ProgramNotUpgradable = 555
Given program is not upgradable
InvalidTokenOwner = 556
Invalid token owner
TokenOwnerMustSign = 557
Current token owner must sign transaction
VoteThresholdPercentageTypeNotSupported = 558
Given VoteThresholdPercentageType is not supported
VoteWeightSourceNotSupported = 559
Given VoteWeightSource is not supported
ProposalCoolOffTimeNotSupported = 560
Proposal cool off time is not supported
GovernancePdaMustSign = 561
Governance PDA must sign
InstructionAlreadyFlaggedWithError = 562
Instruction already flagged with error
InvalidRealmForGovernance = 563
Invalid Realm for Governance
InvalidAuthorityForRealm = 564
Invalid Authority for Realm
RealmHasNoAuthority = 565
Realm has no authority
RealmAuthorityMustSign = 566
Realm authority must sign
InvalidGoverningTokenHoldingAccount = 567
Invalid governing token holding account
RealmCouncilMintChangeIsNotSupported = 568
Realm council mint change is not supported
MintMaxVoteWeightSourceNotSupported = 569
Not supported mint max vote weight source
InvalidMaxVoteWeightSupplyFraction = 570
Invalid max vote weight supply fraction
NotEnoughTokensToCreateGovernance = 571
Owner doesn’t have enough governing tokens to create Governance
TooManyOutstandingProposals = 572
Too many outstanding proposals
AllProposalsMustBeFinalisedToWithdrawGoverningTokens = 573
All proposals must be finalized to withdraw governing tokens
InvalidVoterWeightRecordForRealm = 574
Invalid VoterWeightRecord for Realm
InvalidVoterWeightRecordForGoverningTokenMint = 575
Invalid VoterWeightRecord for GoverningTokenMint
InvalidVoterWeightRecordForTokenOwner = 576
Invalid VoterWeightRecord for TokenOwner
VoterWeightRecordExpired = 577
VoterWeightRecord expired
InvalidRealmConfigForRealm = 578
Invalid RealmConfig for Realm
TokenOwnerRecordAlreadyExists = 579
TokenOwnerRecord already exists
GoverningTokenDepositsNotAllowed = 580
Governing token deposits not allowed